==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/spellchecker.php <==
<?php

/**
  @class SpellChecker
  @brief Class for spell checking.
  @author Martin Zlomek
  @date 25-03-2006
 */
class SpellChecker {
	/** Dictionary link identifier. */
	private $dict;

	/** Any word has been added to the custom dictionary? */
	private $custom;

	/**
	  @brief Open the spellchecker.
	  @param $lang The two letter ISO 639 language code
	  and an optional two letter ISO 3166 country code after a dash or underscore.
	  $custom Path to the custom dictionary.
	 */
	public function __construct($lang, $custom = '')
	{
		/* Create the spell config. */
		$config = pspell_config_create($lang, '', '', 'UTF-8');

		/* Set the spellchecker mode of number of suggestions returned. */
		if (!pspell_config_mode($config, PSPELL_FAST))
			throw new Exc('Cannot set the spellchecker mode');

		/* Open the personal dictionary. */
		if ($custom && !pspell_config_personal($config, $custom))
			throw new Exc('Cannot open the custom dictionary');

		/* Open the dictionary. */
		$this->dict	= pspell_new_config($config);
		$this->custom = false;
	}

	/**
	  @brief Close the spellchecker.
	 */
	public function __destruct()
	{
		if ($this->custom)
			pspell_save_wordlist($this->dict);
	}

	/**
	  @brief Spellcheck a text.
	  @param $text The text.
	  @param $suggest Generate suggested spellings for each misspelled word?
	  @return Misspelled words as an array of (word => array of suggest spellings).
	 */
	public function check($text, $suggest)
	{
		$misspelled = array();

		mb_regex_encoding('UTF-8');
		mb_ereg_search_init($text, "[^[:alpha:]]*([[:alpha:]]+[']?[[:alpha:]]+)");
		while (($regs = mb_ereg_search_regs()) !== false) {
			$word = $regs[1];
			if (!pspell_check($this->dict, $word))
				$misspelled[$word] = $suggest ? $this->suggest($word) : array();
		}

		return $misspelled;
	}

	/**
	  @brief Suggest spellings of a word.
	  @param $word The word.
	  @return Array of possible spellings for the word.
	 */
	public function suggest($word)
	{
		return pspell_suggest($this->dict, $word);
	}

	/**
	  @brief Add a word to the custom dictionary.
	  @param $work The word.
	 */
	public function add($word)
	{
		if (!pspell_add_to_personal($this->dict, $word))
			throw new Exc('Cannot add the word to the custom dictionary');

		$this->custom = true;
	}
}

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/spellchecker.php <==
<?php

/**
  @class SpellChecker
  @brief Class for spell checking.
  @author Martin Zlomek
  @date 25-03-2006
 */
class SpellChecker {
	/** Dictionary link identifier. */
	private $dict;

	/** Any word has been added to the custom dictionary? */
	private $custom;

	/**
	  @brief Open the spellchecker.
	  @param $lang The two letter ISO 639 language code
	  and an optional two letter ISO 3166 country code after a dash or underscore.
	  $custom Path to the custom dictionary.
	 */
	public function __construct($lang, $custom = '')
	{
		/* Create the spell config. */
		$config = pspell_config_create($lang, '', '', 'UTF-8');

		/* Set the spellchecker mode of number of suggestions returned. */
		if (!pspell_config_mode($config, PSPELL_FAST))
			throw new Exc('spellchecker_set_mode');

		/* Open the personal dictionary. */
		if ($custom && !pspell_config_personal($config, $custom))
			throw new Exc('spellchecker_open_dictionary',$custom);

		/* Open the dictionary. */
		$this->dict	= pspell_new_config($config);
		$this->custom = false;
	}

	/**
	  @brief Close the spellchecker.
	 */
	public function __destruct()
	{
		if ($this->custom)
			pspell_save_wordlist($this->dict);
	}

	/**
	  @brief Spellcheck a text.
	  @param $text The text.
	  @param $suggest Generate suggested spellings for each misspelled word?
	  @return Misspelled words as an array of (word => array of suggest spellings).
	 */
	public function check($text, $suggest)
	{
		$misspelled = array();

		mb_regex_encoding('UTF-8');
		mb_ereg_search_init($text, "[^[:alpha:]]*([[:alpha:]]+[']?[[:alpha:]]+)");
		while (($regs = mb_ereg_search_regs()) !== false) {
			$word = $regs[1];
			if (!pspell_check($this->dict, $word))
				$misspelled[$word] = $suggest ? $this->suggest($word) : array();
		}

		return $misspelled;
	}

	/**
	  @brief Suggest spellings of a word.
	  @param $word The word.
	  @return Array of possible spellings for the word.
	 */
	public function suggest($word)
	{
		return pspell_suggest($this->dict, $word);
	}

	/**
	  @brief Add a word to the custom dictionary.
	  @param $work The word.
	 */
	public function add($word)
	{
		if (!pspell_add_to_personal($this->dict, $word))
			throw new Exc('spellchecker_add_word',$word);

		$this->custom = true;
	}
}

?>
